/**
 * @author luotao 2017-12-11
 */
import { IdDTO, IdNameDTO } from "../../index";
import { WorkflowNodeTypeEnum, WorkflowNotifyWayEnum, WorkflowRuleEnum, WorkflowStatusEnum } from "../../../enum/index";
import { WorkflowInstanceDTO } from "./WorkflowInstanceDTO";
import { WorkflowTaskDTO } from "./WorkflowTaskDTO";
/**
 * 流程
 * @backend ytd.iam.workflow.param.WorkflowVO.Workflow
 */
declare class WorkflowDTO extends IdNameDTO {
    static readonly className: string;
    /** 状态 */
    status: WorkflowStatusEnum;
    /** 备注 */
    notes: string;
    /** 标签 */
    tag: string;
    /** 时间戳 */
    ts: string;
    /** 地址 */
    url: string;
    /** 路由 */
    route: string;
    /** 点 */
    nodes: Array<WorkflowDTO.NodeDTO>;
    /** 线 */
    edges: Array<WorkflowDTO.EdgeDTO>;
    rules: Array<WorkflowDTO.Rule>;
    constructor(dto?: {
        id?: string | null;
        name?: string | null;
        status?: WorkflowStatusEnum | null;
        notes?: string | null;
        tag?: string | null;
        url?: string | null;
        ts?: string | null;
        route?: string | null;
        nodes?: Array<WorkflowDTO.NodeDTO> | null;
        edges?: Array<WorkflowDTO.EdgeDTO> | null;
        rules?: Array<WorkflowDTO.Rule> | null;
    } | null);
}
declare namespace WorkflowDTO {
    import TaskItemDTO = WorkflowTaskDTO.TaskItemDTO;
    /**
     * 点
     * @backend ytd.iam.workflow.param.WorkflowVO.Node
     */
    class NodeDTO extends IdNameDTO {
        static readonly className: string;
        /** 节点类型 */
        type: WorkflowNodeTypeEnum;
        /** 参与者 */
        participant: Participant;
        /** 坐标 */
        coordinate: Coordinate;
        /** 是否是开始节点 */
        start: boolean;
        /** 是否是结束节点 */
        final: boolean;
        rules: Array<WorkflowDTO.Rule>;
        constructor(dto?: {
            id?: string | null;
            name?: string | null;
            type?: WorkflowNodeTypeEnum | null;
            participant?: Participant | null;
            coordinate?: Coordinate | null;
            start?: boolean | null;
            final?: boolean | null;
            rules?: Array<WorkflowDTO.Rule> | null;
        } | null);
    }
    /**
     * 线
     * @backend ytd.iam.workflow.param.WorkflowVO.Edge
     */
    class EdgeDTO extends IdDTO {
        static readonly className: string;
        start: string;
        end: string;
        label: string;
        action: string;
        /** 是否是到'结束节点'那条边 */
        finalEdge: boolean;
        /** 通知方式 */
        notify: WorkflowDTO.Notify;
        /** 规则 */
        rules: Array<WorkflowDTO.Rule>;
        constructor(dto?: {
            id?: string | null;
            start?: string | null;
            end?: string | null;
            label?: string | null;
            action?: string | null;
            finalEdge?: boolean | null;
            notify?: WorkflowDTO.Notify | null;
            rules?: Array<WorkflowDTO.Rule> | null;
        } | null);
    }
    /**
     * 业务对象
     * @backend ytd.iam.workflow.param.WorkflowVO.Bo
     */
    class BO extends IdDTO {
        static readonly className: string;
        /** 业务对象类型 */
        clazz: string;
        properties: Array<Pair>;
        constructor(dto?: {
            id?: string | null;
            clazz?: string | null;
            properties?: Array<Pair> | null;
        } | null);
    }
    /**
     * 路径
     * @backend ytd.iam.workflow.param.WorkflowVO.Path
     */
    class Path extends IdDTO {
        static readonly className: string;
        /** 参与人，应用账号标识 */
        appAccountId: string;
        /** 留言 */
        message: string;
        /** 业务对象 */
        bo: BO;
        /** 通知内容 */
        notifyMessage: string;
        constructor(dto?: {
            id?: string | null;
            appAccountId?: string | null;
            message?: string | null;
            bo?: BO | null;
            notifyMessage?: string | null;
        } | null);
    }
    /**
     * 参与者
     * @backend ytd.iam.workflow.param.WorkflowVO.Participant
     */
    class Participant {
        static readonly className: string;
        all: boolean;
        roles: Set<string>;
        labels: Set<string>;
        accounts: Set<string>;
        model: number;
        /**
         * 是否选择发起者
         */
        sponsor: boolean;
        constructor(dto?: {
            all?: boolean | null;
            roles?: Set<string> | null;
            labels?: Set<string> | null;
            accounts?: Set<string> | null;
            model?: number | null;
            sponsor?: boolean | null;
        } | null);
    }
    /**
     * 坐标
     * @backend ytd.iam.workflow.param.WorkflowVO.Coordinate
     */
    class Coordinate {
        static readonly className: string;
        x: number;
        y: number;
        constructor(dto?: {
            x?: number | null;
            y?: number | null;
        } | null);
        /**
         * @deprecated
         */
        static from(tb: Coordinate | null): Coordinate;
        /**
         * @deprecated
         */
        static fromArray(tbs: Coordinate[]): Coordinate[];
    }
    /**
     * 轨迹节点
     * @backend ytd.iam.workflow.param.WorkflowVO.TrackNode
     */
    class TrackNodeDTO {
        static readonly className: string;
        index: number;
        node: NodeDTO;
        /** 正在执行 */
        running: boolean;
        /** 当前节点 */
        current: boolean;
        /** 任务 */
        task: TaskItemDTO;
        /** 操作 */
        operation: OperationDTO;
        constructor(dto?: {
            index?: number | null;
            node?: NodeDTO | null;
            running?: boolean | null;
            current?: boolean | null;
            task?: TaskItemDTO | null;
            operation?: OperationDTO | null;
        } | null);
        /**
         * @deprecated
         */
        static from(tb: TrackNodeDTO | null): TrackNodeDTO;
        /**
         * @deprecated
         */
        static fromArray(tbs: TrackNodeDTO[]): TrackNodeDTO[];
    }
    /**
     * 轨迹连线
     * @backend ytd.iam.workflow.param.WorkflowVO.TrackEdge
     */
    class TrackEdgeDTO {
        static readonly className: string;
        index: number;
        edge: EdgeDTO;
        startNode: TrackNodeDTO;
        endNode: TrackNodeDTO;
        constructor(dto?: {
            index?: number | null;
            edge?: EdgeDTO | null;
            startNode?: TrackNodeDTO | null;
            endNode?: TrackNodeDTO | null;
        } | null);
        /**
         * @deprecated
         */
        static from(tb: TrackEdgeDTO | null): TrackEdgeDTO;
        /**
         * @deprecated
         */
        static fromArray(tbs: TrackEdgeDTO[]): TrackEdgeDTO[];
    }
    /**
     * 操作
     * @backend ytd.iam.workflow.param.WorkflowVO.Operation
     */
    class OperationDTO extends IdNameDTO {
        static readonly className: string;
        /** 头像 */
        avatar: string;
        /** 开始时间 */
        startTs: number;
        /** 结束时间 */
        endTs: number;
        /** 花费时间 */
        consume: number;
        constructor(dto?: {
            id?: string | null;
            name?: string | null;
            avatar?: string | null;
            startTs?: number | null;
            endTs?: number | null;
            consume?: number | null;
        } | null);
        /**
         * @deprecated
         */
        static from(tb: OperationDTO | null): OperationDTO;
        /**
         * @deprecated
         */
        static fromArray(tbs: OperationDTO[]): OperationDTO[];
    }
    /**
     * 轨迹
     * @backend ytd.iam.workflow.param.WorkflowVO.Track
     */
    class TrackDTO {
        static readonly className: string;
        /** 流程定义 */
        wf: WorkflowDTO;
        /** 流程实例 */
        instance: WorkflowInstanceDTO;
        nodes: Array<TrackNodeDTO>;
        edges: Array<TrackEdgeDTO>;
        constructor(dto?: {
            wf?: WorkflowDTO | null;
            instance?: WorkflowInstanceDTO | null;
            nodes?: Array<TrackNodeDTO> | null;
            edges?: Array<TrackEdgeDTO> | null;
        } | null);
        /**
         * @deprecated
         */
        static from(tb: TrackDTO | null): TrackDTO;
        /**
         * @deprecated
         */
        static fromArray(tbs: TrackDTO[]): TrackDTO[];
    }
    /**
     * 通知
     * @backend ytd.iam.workflow.param.WorkflowVO.Notify
     */
    class Notify {
        static readonly className: string;
        /**
         * 通知方式
         */
        way: Array<WorkflowNotifyWayEnum>;
        constructor(notifyDTO?: {
            way?: Array<WorkflowNotifyWayEnum> | null;
        } | null);
    }
    /**
     * @backend ytd.iam.workflow.param.WorkflowVO.Pair
     */
    class Pair {
        static readonly className: string;
        key: string;
        value: string;
        constructor(dto?: {
            key?: string | null;
            value?: string | null;
        } | null);
    }
    /**
     * @backend ytd.iam.workflow.param.WorkflowVO.Rule
     */
    class Rule {
        static readonly className: string;
        name: WorkflowRuleEnum;
        script: string;
        constructor(dto?: {
            name?: WorkflowRuleEnum | null;
            script?: string | null;
        } | null);
    }
    /**
     * 工作时限
     * @backend ytd.iam.workflow.param.WorkflowVO.WorkTime
     */
    class WorkTime {
        static readonly className: string;
        /** 值 */
        value: number;
        /** 单位（D/H/M） */
        unit: string;
        second: number;
        constructor(dto?: {
            value?: number | null;
            unit?: string | null;
            second?: number | null;
        } | null);
    }
    /**
     * 工作时限状态
     * @backend ytd.iam.workflow.param.WorkflowVO.WorkTimeStatus
     */
    class WorkTimeStatus {
        static readonly className: string;
        status: number;
        /**
         * 百分比
         */
        percent: number;
        /**
         * 剩余时间（秒）
         */
        remaining: number;
        constructor(dto?: {
            status?: number | null;
            percent?: number | null;
            remaining?: number | null;
        } | null);
    }
}
export { WorkflowDTO };
