/**
 * @author luotao 2017-12-08
 */
import { AppAccountDTO, RestResultDTO } from "../dto/index";
import { AppCodeEnum } from "../enum/index";
import { HttpClient } from "./HttpClient";
import { IService } from "./IService";
/**
 * 认证 & 授权
 */
declare class AuthService implements IService {
    httpClient?: HttpClient;
    /** 应用编码 */
    readonly appCode: AppCodeEnum;
    /** 是否是生产环境 */
    readonly isProduction: boolean;
    /**
     * 未授权的动作权限编码列表获取方法
     * 为了增加扩展性，由调用者提供列表的获取方法；
     */
    unauthorizedPermissionCodesGetter: () => Array<string>;
    constructor(appCode: AppCodeEnum, isProduction: boolean, unauthorizedPermissionCodesGetter?: () => Array<string>);
    /**
     * 动作权限是否已经授权
     * @param actionCode 动作权限编码
     */
    isActionAuthorized(actionCode: string): boolean;
    /**
     * 获取本地保存的登录 token
     */
    getToken(): string;
    /**
     * 设置本地保存的登录 token
     * @param token
     */
    setToken(token: string): void;
    /**
     * 删除本地保存的登录 token
     */
    removeToken(): void;
    /**
     * 获取本地保存的应用账户
     * @returns 应用账户
     */
    getUser(): AppAccountDTO;
    /**
     * 设置本地保存的应用账户
     * @param appAccount 应用账户
     */
    setUser(appAccount: AppAccountDTO): Promise<AppAccountDTO>;
    /**
     * 删除本地保存的应用账户
     */
    removeUser(): void;
    /**
     * 检查是否已经认证
     */
    isAuthenticated(): Promise<RestResultDTO<boolean>>;
    /**
     * 退出登录
     *
     * @param op 操作码；SSO 根据该操作码执行相应的操作；
     */
    logout(op?: string): void;
}
export { AuthService };
