/**
 * @author luotao 2017-12-08
 */
import { AxiosRequestConfig } from "axios";
import { RestResultDTO } from "../dto";
import { AuthService } from "./AuthService";
/** 错误处理函数 */
declare type IErrorHandler = (statusCode: number, message: string) => void;
/** 请求配置 */
interface IRequestConfig extends AxiosRequestConfig {
    /** 是否阻止提示错误消息 */
    suppressErrorMessage?: boolean;
}
declare class HttpClient {
    /** 无需授权的地址白名单 */
    static authWhitelist: Array<RegExp>;
    readonly authService: AuthService;
    /** 是否是生产环境 */
    private readonly isProduction;
    /** 认证&授权服务 */
    /** 错误处理函数 */
    readonly errorHandler: IErrorHandler;
    constructor(isProduction: boolean, authService: AuthService, errorHandler?: IErrorHandler);
    /**
     * 转义查询参数
     * @deprecated
     * @param queryString 查询参数
     */
    encodeQueryString(queryString: string): string;
    /**
     * 转义查询参数
     * @param queryString 查询参数
     */
    encode(queryString?: string | null): string;
    /**
     *
     * @param url
     * @param requestConfig
     * @returns
     */
    get<T>(url: string, requestConfig?: IRequestConfig): Promise<RestResultDTO<T>>;
    /**
     *
     * @param url
     * @param obj
     * @param requestConfig
     * @returns
     */
    post<T>(url: string, obj?: object | string, requestConfig?: IRequestConfig): Promise<RestResultDTO<T>>;
    /**
     *
     * @param url
     * @param obj
     * @param requestConfig
     * @returns
     */
    patch<T>(url: string, obj?: object | string, requestConfig?: IRequestConfig): Promise<RestResultDTO<T>>;
    /**
     *
     * @param url
     * @param requestConfig
     * @returns
     */
    del<T>(url: string, requestConfig?: IRequestConfig): Promise<RestResultDTO<T>>;
    /**
     * 构造请求地址，添加时间戳参数，在开发环境禁用缓存
     * @param url 请求地址
     */
    private getUrlWithTimestamp;
    /**
     *
     * @param response
     * @param suppressErrorMessage 是否阻止提示错误消息
     */
    private handleSuccess;
    /**
     *
     * @param error
     * @param suppressErrorMessage 阻止提示错误消息
     */
    private handleError;
}
export { IRequestConfig, IErrorHandler, HttpClient };
