/**
 * @author luotao 2017-12-16
 */
import { IService } from "../../IService";
import { HttpClient } from "../../HttpClient";
import { ActionDTO, ToggleStatusDTO } from "../../../dto/index";
import { SaveActionRO } from "../../../ro/index";
/**
 * 操作
 * @backend ytd.iam.admin.api.ActionService
 */
declare class ActionService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 列表查询操作，根据应用ID
     * @backend ytd.iam.admin.api.ActionService#findAll
     *
     * @param appId 应用ID
     * @returns {Promise<ActionDTO[]>}
     */
    listActionByAppId(appId: string): Promise<ActionDTO[]>;
    /**
     * 列表查询操作，根据应用ID和资源类型
     * @backend ytd.iam.admin.api.ActionService#findAll2
     *
     * @param appId 应用ID
     * @param resourceType 资源类型
     * @returns {Promise<ActionDTO[]>}
     */
    listActionByAppIdAndResourceType(appId: string, resourceType: number): Promise<ActionDTO[]>;
    /**
     * 查询操作
     * @backend ytd.iam.admin.api.ActionService#findDetail
     *
     * @param actionId 操作ID
     * @returns {Promise<ActionDTO>}
     */
    getAction(actionId: string): Promise<ActionDTO>;
    /**
     * 添加操作
     * @backend ytd.iam.admin.api.ActionService#add
     *
     * @param {SaveActionRO} saveActionRO
     * @returns {Promise<ActionDTO>}
     */
    addAction(saveActionRO: SaveActionRO): Promise<ActionDTO>;
    /**
     * 编辑操作
     * @backend ytd.iam.admin.api.ActionService#update
     *
     * @param actionId 操作ID
     * @param {SaveActionRO} saveActionRO
     * @returns {Promise<ActionDTO>}
     */
    updateAction(actionId: string, saveActionRO: SaveActionRO): Promise<ActionDTO>;
    /**
     * 启用&禁用操作
     * @backend ytd.iam.admin.api.ActionService#enabled
     *
     * @param actionId 操作ID
     * @returns {Promise<ToggleStatusDTO>}
     */
    toggleAction(actionId: string): Promise<ToggleStatusDTO>;
    /**
     * 删除操作
     * @backend ytd.iam.admin.api.ActionService#delete
     *
     * @param actionId 操作ID
     * @returns {Promise<string>}
     */
    deleteAction(actionId: string): Promise<string>;
}
export { ActionService };
