/**
 * @author luotao 2017-12-19
 */
import { AppAccountDTO, AppAccountProfileDTO, PageDTO } from "../../../dto/index";
import { SaveAppAccountProfileRO, SaveTagRO } from "../../../ro/index";
import { HttpClient } from "../../HttpClient";
import { IService } from "../../IService";
/**
 * 应用账户
 * @backend ytd.iam.admin.api.AppAccountService
 */
declare class AppAccountService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 查询应用账户
     * @backend ytd.iam.admin.api.AppAccountService#find
     */
    getAppAccount(appAccountId: string): Promise<AppAccountDTO>;
    /**
     * 分页查询应用账户
     * @backend ytd.iam.admin.api.AppAccountService#findAll2
     *
     * @param pageIndex
     * @param pageSize
     * @param appId 应用ID
     * @param key 关键字
     */
    pageAppAccount(pageIndex: number, pageSize: number, appId: string, key: string): Promise<PageDTO<AppAccountDTO>>;
    /**
     * 查询所有标签
     * @backend ytd.iam.admin.api.AppAccountService#findAllTags
     */
    listTags(): Promise<Array<string>>;
    /**
     * 添加标签
     * @backend ytd.iam.admin.api.AppAccountService#addTag
     *
     * @param id 账户ID
     * @param saveTagRO
     */
    addTag(id: string, saveTagRO: SaveTagRO): Promise<string>;
    /**
     * 删除标签
     * @backend ytd.iam.admin.api.AppAccountService#deleteTag
     *
     * @param id 账户ID
     * @param tag 标签
     */
    deleteTag(id: string, tag: string): Promise<string>;
    /**
     * 获取应用账户配置
     * @backend ytd.iam.admin.api.AppAccountService#findProfile
     *
     * @param key KEY
     * @param workspace 工作空间
     */
    getProfile(key: string, workspace?: string): Promise<AppAccountProfileDTO>;
    /**
     * 保存应用账户配置
     * @backend ytd.iam.admin.api.AppAccountService#addOrUpdateProfile
     *
     * @param saveAppAccountProfileRO
     */
    saveProfile(saveAppAccountProfileRO: SaveAppAccountProfileRO): Promise<string>;
}
export { AppAccountService };
