/**
 * @author luotao 2017-12-11
 */
import { IService } from "../../IService";
import { HttpClient } from "../../HttpClient";
import { MenuDTO, ToggleStatusDTO } from "../../../dto/index";
import { SaveMenuRO } from "../../../ro/index";
/**
 * 菜单
 * @backend ytd.iam.admin.api.MenuService
 */
declare class MenuService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 查询菜单树
     * @backend ytd.iam.admin.api.MenuService#findAll
     *
     * @param appId 应用ID
     * @returns {Promise<MenuDTO[]>}
     */
    listMenuByAppId(appId: string): Promise<MenuDTO[]>;
    /**
     * 查询菜单
     * @backend ytd.iam.admin.api.MenuService#findDetail
     *
     * @param menuId 菜单ID
     * @returns {Promise<MenuDTO>}
     */
    getMenu(menuId: string): Promise<MenuDTO>;
    /**
     * 添加菜单
     * @backend ytd.iam.admin.api.MenuService#add
     *
     * @param {SaveMenuRO} saveMenuRO
     * @returns {Promise<MenuDTO>}
     */
    addMenu(saveMenuRO: SaveMenuRO): Promise<MenuDTO>;
    /**
     * 编辑菜单
     * @backend ytd.iam.admin.api.MenuService#update
     *
     * @param menuId 菜单ID
     * @param {SaveMenuRO} saveMenuRO
     * @returns {Promise<MenuDTO>}
     */
    updateMenu(menuId: string, saveMenuRO: SaveMenuRO): Promise<MenuDTO>;
    /**
     * 启用&禁用菜单
     * @backend ytd.iam.admin.api.MenuService#enabled
     *
     * @param menuId 菜单ID
     * @returns {Promise<ToggleStatusDTO>}
     */
    toggleMenu(menuId: string): Promise<ToggleStatusDTO>;
    /**
     * 删除菜单
     * @backend ytd.iam.admin.api.MenuService#delete
     *
     * @param menuId 菜单ID
     * @returns {Promise<string>}
     */
    removeMenu(menuId: string): Promise<string>;
}
export { MenuService };
