/**
 * @author luotao 2016-12-11
 */
import { IService } from "../../IService";
import { HttpClient } from "../../HttpClient";
import { PageDTO, RoleDTO, ToggleStatusDTO } from "../../../dto/index";
import { SaveRoleRO } from "../../../ro/index";
/**
 * 角色
 * @backend ytd.iam.admin.api.RoleService
 */
declare class RoleService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 分页查询角色
     * @backend ytd.iam.admin.api.RoleService#findAll
     *
     * @param appId 应用ID
     * @param key
     * @param pageIndex
     * @param pageSize
     * @returns {Promise<PageDTO<RoleDTO>>}
     */
    pageRole(appId: string, key: string, pageIndex: number, pageSize: number): Promise<PageDTO<RoleDTO>>;
    /**
     * 查询角色
     * @backend ytd.iam.admin.api.RoleService#findDetail
     *
     * @param roleId 角色ID
     * @returns {Promise<RoleDTO>}
     */
    getRole(roleId: string): Promise<RoleDTO>;
    /**
     * 添加角色
     * @backend ytd.iam.admin.api.RoleService#add
     *
     * @param {SaveRoleRO} saveRoleRO
     * @returns {Promise<RoleDTO>}
     */
    addRole(saveRoleRO: SaveRoleRO): Promise<RoleDTO>;
    /**
     * 编辑角色
     * @backend ytd.iam.admin.api.RoleService#update
     *
     * @param roleId 角色ID
     * @param {SaveRoleRO} saveRoleRO
     */
    updateRole(roleId: string, saveRoleRO: SaveRoleRO): Promise<RoleDTO>;
    /**
     * 启用&禁用角色
     * @backend ytd.iam.admin.api.RoleService#enabled
     *
     * @param roleId 角色ID
     * @returns {Promise<ToggleStatusDTO>}
     */
    toggleRole(roleId: string): Promise<ToggleStatusDTO>;
    /**
     * 删除角色
     * @backend ytd.iam.admin.api.RoleService#delete
     *
     * @param roleId 角色ID
     * @returns {Promise<string>}
     */
    removeRole(roleId: string): Promise<string>;
}
export { RoleService };
