/**
 * @author luotao 2017-12-11
 */
import { PageDTO, SelectedAppAccountDTO, WorkflowDTO, WorkflowTaskDTO } from "../../../dto/index";
import { AddEdgeRO, AddNodeRO, AddWorkflowRO, SponsorRO, StartupWorkflowRO, UpdateEdgeRO, UpdateNodeRO, UpdateWorkflowRO } from "../../../ro/index";
import { HttpClient } from "../../HttpClient";
import { IService } from "../../IService";
/**
 * 流程
 * @backend ytd.iam.workflow.api.WorkflowService
 */
declare class WorkflowService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 分页查询流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#page
     *
     * @param pageIndex
     * @param pageSize
     * @param sponsorRO
     * @returns {Promise<PageDTO<WorkflowDTO>>}
     */
    pageWorkflow(pageIndex: number, pageSize: number, sponsorRO: SponsorRO): Promise<PageDTO<WorkflowDTO>>;
    /**
     * 分页查询发布的流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#pageRelease
     *
     * @param pageIndex
     * @param pageSize
     * @returns {Promise<PageDTO<WorkflowDTO>>}
     */
    pageReleasedWorkflow(pageIndex: number, pageSize: number, sponsorRO: SponsorRO): Promise<PageDTO<WorkflowDTO>>;
    /**
     * 查询流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#workflow
     *
     * @param workflowId 流程ID
     * @returns {Promise<WorkflowDTO>}
     */
    getWorkflow(workflowId: string): Promise<WorkflowDTO>;
    /**
     * 查询流程定义，根据标签（tag）
     * @backend ytd.iam.workflow.api.WorkflowService#findReleaseByTag
     *
     * @param tag 标签
     * @returns {Promise<WorkflowDTO>}
     */
    getWorkflowByTag(tag: string): Promise<WorkflowDTO>;
    /**
     * 添加流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#createWorkflow
     *
     * @param addWorkflowRO
     * @returns {Promise<string>}
     */
    addWorkflow(addWorkflowRO: AddWorkflowRO): Promise<string>;
    /**
     * 编辑流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#updateWorkflow
     *
     * @param workflowId 流程ID
     * @param {UpdateWorkflowRO} updateWorkflowRO
     * @returns {Promise<string>}
     */
    updateWorkflow(workflowId: string, updateWorkflowRO: UpdateWorkflowRO): Promise<string>;
    /**
     * 启动流程实例
     * @backend ytd.iam.workflow.api.WorkflowService#startupWorkflow
     *
     * @param workflowId 流程ID
     * @param {StartupWorkflowRO} startupWorkflowRO
     * @returns {Promise<string>}
     */
    startWorkflow(workflowId: string, startupWorkflowRO: StartupWorkflowRO): Promise<string>;
    /**
     * 删除流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#deleteWorkflow
     *
     * @param workflowId 流程ID
     * @returns {Promise<string>}
     */
    deleteWorkflow(workflowId: string): Promise<string>;
    /**
     * 克隆流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#copyWorkflow
     *
     * @param workflowId 流程ID
     * @returns {Promise<string>}
     */
    cloneWorkflow(workflowId: string): Promise<string>;
    /**
     * 发布流程定义
     * @backend ytd.iam.workflow.api.WorkflowService#release
     *
     * @param workflowId 流程ID
     * @returns {Promise<string>}
     */
    releaseWorkflow(workflowId: string): Promise<string>;
    /**
     * 查询所有节点
     * @backend ytd.iam.workflow.api.WorkflowService#allNodes
     *
     * @param workflowId 流程ID
     * @returns {Promise<WorkflowDTO.NodeDTO[]>}
     */
    listNode(workflowId: string): Promise<WorkflowDTO.NodeDTO[]>;
    /**
     * 添加节点
     * @backend ytd.iam.workflow.api.WorkflowService#createNode
     *
     * @param workflowId 流程ID
     * @param {AddNodeRO} addNodeRO
     * @returns {Promise<string>}
     */
    addNode(workflowId: string, addNodeRO: AddNodeRO): Promise<string>;
    /**
     * 编辑节点
     * @backend ytd.iam.workflow.api.WorkflowService#updateNode
     *
     * @param workflowId 流程ID
     * @param nodeId 节点ID
     * @param {AddNodeRO} uddateNodeRO
     * @returns {Promise<string>}
     */
    updateNode(workflowId: string, nodeId: string, uddateNodeRO: UpdateNodeRO): Promise<string>;
    /**
     * 移动节点，更新坐标
     * @backend ytd.iam.workflow.api.WorkflowService#moveNode
     *
     * @param workflowId 流程ID
     * @param nodeId 节点ID
     * @param {WorkflowDTO.Coordinate} coordinate 坐标
     * @returns {Promise<string>}
     */
    moveNode(workflowId: string, nodeId: string, coordinate: WorkflowDTO.Coordinate): Promise<string>;
    /**
     * 删除节点
     * @backend ytd.iam.workflow.api.WorkflowService#deleteNode
     *
     * @param workflowId 流程ID
     * @param nodeId 节点ID
     * @returns {Promise<string>}
     */
    deleteNode(workflowId: string, nodeId: string): Promise<string>;
    /**
     * 查询所有线
     * @backend ytd.iam.workflow.api.WorkflowService#allEdges
     *
     * @param workflowId 流程ID
     * @returns {Promise<WorkflowDTO.EdgeDTO[]>}
     */
    listEdge(workflowId: string): Promise<WorkflowDTO.EdgeDTO[]>;
    /**
     * 添加线
     * @backend ytd.iam.workflow.api.WorkflowService#createEdge
     *
     * @param workflowId 流程ID
     * @param {AddEdgeRO} addEdgeRO
     * @returns {Promise<string>}
     */
    addEdge(workflowId: string, addEdgeRO: AddEdgeRO): Promise<string>;
    /**
     * 编辑线
     * @backend ytd.iam.workflow.api.WorkflowService#updateEdge
     *
     * @param workflowId 流程ID
     * @param edgeId 线ID
     * @param {AddEdgeRO} uddateEdgeRO
     * @returns {Promise<string>}
     */
    updateEdge(workflowId: string, edgeId: string, uddateEdgeRO: UpdateEdgeRO): Promise<string>;
    /**
     * 删除线
     * @backend ytd.iam.workflow.api.WorkflowService#deleteEdge
     *
     * @param workflowId 流程ID
     * @param edgeId 线ID
     * @returns {Promise<string>}
     */
    deleteEdge(workflowId: string, edgeId: string): Promise<string>;
    /**
     * 根据节点查询线列表
     * @backend ytd.iam.workflow.api.WorkflowService#outEdges
     *
     * @param workflowId 流程ID
     * @param nodeId 节点ID
     * @returns {Promise<WorkflowDTO.EdgeDTO[]>}
     */
    listEdgeByNode(workflowId: string, nodeId: string): Promise<WorkflowDTO.EdgeDTO[]>;
    /**
     * 查询可以启动的线
     * @backend ytd.iam.workflow.api.WorkflowService#startUpEdges
     *
     * @param workflowId 流程ID
     * @returns {Promise<WorkflowDTO.EdgeDTO[]>}
     */
    listStartupEdge(workflowId: string): Promise<WorkflowDTO.EdgeDTO[]>;
    /**
     * 查询代办任务列表
     * @backend ytd.iam.workflow.api.WorkflowService#findMyTask
     *
     * @param pageIndex
     * @param pageSize
     * @returns {Promise<PageDTO<WorkflowTaskDTO>>}
     */
    pageTodoTask(pageIndex: number, pageSize: number, sponsorRO: SponsorRO): Promise<PageDTO<WorkflowTaskDTO>>;
    /**
     * 查询完成任务列表
     * @backend ytd.iam.workflow.api.WorkflowService#findMyCompletedTask
     *
     * @param pageIndex
     * @param pageSize
     * @param sponsorRO
     * @returns {Promise<PageDTO<WorkflowTaskDTO>>}
     */
    pageCompletedTask(pageIndex: number, pageSize: number, sponsorRO: SponsorRO): Promise<PageDTO<WorkflowTaskDTO>>;
    /**
     * 查询我的业务
     * @backend ytd.iam.workflow.api.WorkflowService#findMySponsorBusiness
     *
     * @param pageIndex
     * @param pageSize
     * @param {SponsorRO} sponsorRO
     * @returns {Promise<PageDTO<WorkflowTaskDTO>>}
     */
    pageMyTask(pageIndex: number, pageSize: number, sponsorRO: SponsorRO): Promise<PageDTO<WorkflowTaskDTO>>;
    /**
     * 签收任务
     * @backend ytd.iam.workflow.api.WorkflowService#signIn
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @returns {Promise<string>}
     */
    acceptTask(instanceId: string, taskId: string): Promise<string>;
    /**
     * 拒签任务
     * @backend ytd.iam.workflow.api.WorkflowService#reject
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @returns {Promise<string>}
     */
    rejectTask(instanceId: string, taskId: string): Promise<string>;
    /**
     * 提交任务
     * @backend ytd.iam.workflow.api.WorkflowService#commit
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @param {WorkflowDTO.Path} path
     * @returns {Promise<string>}
     */
    commitTask(instanceId: string, taskId: string, path: WorkflowDTO.Path): Promise<string>;
    /**
     * 回退任务
     * @backend ytd.iam.workflow.api.WorkflowService#rollback
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @returns {Promise<string>}
     */
    rollbackTask(instanceId: string, taskId: string): Promise<string>;
    /**
     * 终止任务
     * @backend ytd.iam.workflow.api.WorkflowService#abort
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @returns {Promise<string>}
     */
    abortTask(instanceId: string, taskId: string): Promise<string>;
    /**
     * 取回任务
     * @backend ytd.iam.workflow.api.WorkflowService#take
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @returns {Promise<string>}
     */
    takeTask(instanceId: string, taskId: string): Promise<string>;
    /**
     * 分页查询节点参与者
     * @backend ytd.iam.workflow.api.WorkflowService#findNodeParticipant
     *
     * @param instanceId 流程实例ID
     * @param taskId 任务ID
     * @param nodeId 节点ID
     * @param pageIndex
     * @param pageSize
     * @returns
     */
    pageParticipant(instanceId: string, taskId: string, nodeId: string, pageIndex: number, pageSize: number): Promise<SelectedAppAccountDTO>;
    /**
     * 查询流程轨迹
     * @backend ytd.iam.workflow.api.WorkflowService#findTrack
     *
     * @param instanceId 流程实例ID
     * @returns {Promise<WorkflowDTO.TrackDTO>}
     */
    getTrack(instanceId: string): Promise<WorkflowDTO.TrackDTO>;
    /**
     * 查询流程工时
     * @backend ytd.iam.workflow.api.WorkflowService#findInstanceWorkTime
     *
     * @param instanceId 流程实例ID
     * @returns
     */
    getInstanceWorktime(instanceId: string): Promise<WorkflowDTO.WorkTimeStatus>;
    /**
     * 查询任务工时
     * @backend ytd.iam.workflow.api.WorkflowService#findTaskWorkTime
     *
     * @param taskId 任务 ID
     * @returns
     */
    getTaskWorktime(taskId: string): Promise<WorkflowDTO.WorkTimeStatus>;
    /**
     * 查询未完成的任务
     * @backend ytd.iam.workflow.api.WorkflowService#findUnfinishedTask
     *
     * @param taskId 任务 ID
     * @returns
     */
    listUnfinishedTask(taskId: string): Promise<Array<WorkflowTaskDTO>>;
    /**
     * 查询执行中的任务
     * @backend ytd.iam.workflow.api.WorkflowService#findTaskWorkTime
     *
     * @param taskId 任务 ID
     * @returns
     */
    listExecutingTask(taskId: string): Promise<Array<WorkflowTaskDTO>>;
}
export { WorkflowService };
