/**
 * @author luotao 2018-06-19
 */
import { Geometry } from "geojson";
import { GeoAttributeDTO, IdDTO, PageDTO } from "../../../dto/index";
import { GeomRO, UpdateGeomRO } from "../../../ro/index";
import { HttpClient } from "../../HttpClient";
import { IService } from "../../IService";
/**
 * GIS
 * @backend ytd.pdnms.gis.api.GeomService
 */
declare class GeomService implements IService {
    httpClient: HttpClient;
    constructor(httpClient: HttpClient);
    /**
     * 根据关键字查询资源
     * @backend ytd.pdnms.gis.api.GeomService#query
     * @param pageIndex
     * @param pageSize
     * @param app 应用编码
     * @param key 关键字
     * @param isProject 是否是'配网工程项目'
     */
    query(pageIndex: number, pageSize: number, app: string, key: string, isProject?: number): Promise<PageDTO<GeoAttributeDTO>>;
    /**
     * 查询GeoJSON
     * @backend ytd.pdnms.gis.api.GeomService#location
     *
     * @param id 资源ID
     * @param tableName 表名
     */
    getGeoJSON(id: string, tableName: string): Promise<Geometry>;
    /**
     * 添加GeoJSON
     * @backend ytd.pdnms.gis.api.GeomService#insert
     *
     * @param geomRO
     */
    addGeoJSON(geomRO: GeomRO): Promise<IdDTO>;
    /**
     * 编辑GeoJSON
     * @backend ytd.pdnms.gis.api.GeomService#update
     *
     * @param geomRO
     */
    updateGeoJSON(geomRO: GeomRO): Promise<IdDTO>;
    /**
     * 编辑GeoJSON坐标
     * @backend ytd.pdnms.gis.api.GeomService#updateGeom
     *
     * @param updateGeomRO
     */
    updateGeometry(updateGeomRO: UpdateGeomRO): Promise<IdDTO>;
    /**
     * 删除GeoJSON
     * @backend ytd.pdnms.gis.api.GeomService#delete
     *
     * @param id
     * @param tableName
     */
    deleteGeoJSON(id: string, tableName: string): Promise<IdDTO>;
}
export { GeomService };
